==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/rest/resources/GetImagesResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;

import io.intino.goros.unit.box.schemas.*;

public class GetImagesResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public GetImagesResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.GetImagesAction()).execute());
	}

	private io.intino.goros.unit.box.actions.GetImagesAction fill(io.intino.goros.unit.box.actions.GetImagesAction action) {
		action.box = this.box;
		action.context = context();
		action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromPath("id"), String.class);
		action.path = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromPath("path"), String.class);
		return action;
	}

	private void write(io.intino.alexandria.Resource object) {
		manager.write(object);
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}

==> unit-1.1.25-sources.jar: io/intino/goros/unit/box/rest/resources/GetImagesResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;

import io.intino.goros.unit.box.schemas.*;

public class GetImagesResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public GetImagesResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.GetImagesAction()).execute());
	}

	private io.intino.goros.unit.box.actions.GetImagesAction fill(io.intino.goros.unit.box.actions.GetImagesAction action) throws AlexandriaException {
		action.box = this.box;
		action.context = context();
		try {
			action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromPath("id"), String.class);
			action.path = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromPath("path"), String.class);
		} catch (Throwable e) {
			action.onMalformedRequest(e);
		}
		return action;
	}

	private void write(io.intino.alexandria.Resource object) {
		manager.write(object);
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}
